@@ -4,7 +4,6 @@ import logging
 import os
 import re
 from datetime import date
-from functools import wraps
 from pathlib import Path, PurePath
 from typing import List, Optional, Tuple
 from urllib.parse import urlsplit
@@ -17,24 +16,19 @@ from .errors import GitError, HvcsRepoParseError
 from .helpers import LoggedFunction
 from .settings import config
 
+_repo: Optional[Repo]
 try:
-    repo = Repo(".", search_parent_directories=True)
+    _repo = Repo(".", search_parent_directories=True)
 except InvalidGitRepositoryError:
-    pass
+    _repo = None
 
 logger = logging.getLogger(__name__)
 
 
-def check_repo(func):
-    """Decorator which checks that we are in a git repository."""
-
-    @wraps(func)
-    def function_wrapper(*args, **kwargs):
-        if repo is None:
-            raise GitError("Not in a valid git repository")
-        return func(*args, **kwargs)
-
-    return function_wrapper
+def repo():
+    if _repo is None:
+        raise GitError("Not in a valid git repository")
+    return _repo
 
 
 def get_formatted_tag(version):
@@ -43,25 +37,23 @@ def get_formatted_tag(version):
     return tag_format.format(version=version)
 
 
-@check_repo
 def get_commit_log(from_rev=None):
     """Yield all commit messages from last to first."""
     rev = None
     if from_rev:
         from_rev = get_formatted_tag(from_rev)
         try:
-            repo.commit(from_rev)
+            repo().commit(from_rev)
             rev = f"...{from_rev}"
         except BadName:
             logger.debug(
                 f"Reference {from_rev} does not exist, considering entire history"
             )
 
-    for commit in repo.iter_commits(rev):
+    for commit in repo().iter_commits(rev):
         yield (commit.hexsha, commit.message.replace("\r\n", "\n"))
 
 
-@check_repo
 @LoggedFunction(logger)
 def get_last_version(pattern, skip_tags=None) -> Optional[str]:
     """
@@ -76,7 +68,7 @@ def get_last_version(pattern, skip_tags=None) -> Optional[str]:
             return tag.tag.tagged_date
         return tag.commit.committed_date
 
-    for i in sorted(repo.tags, reverse=True, key=version_finder):
+    for i in sorted(repo().tags, reverse=True, key=version_finder):
         if i.name in skip_tags:
             continue
 
@@ -87,7 +79,6 @@ def get_last_version(pattern, skip_tags=None) -> Optional[str]:
     return None
 
 
-@check_repo
 @LoggedFunction(logger)
 def get_repository_owner_and_name() -> Tuple[str, str]:
     """
@@ -105,7 +96,7 @@ def get_repository_owner_and_name() -> Tuple[str, str]:
         return owner, name
 
     # Local context
-    url = repo.remote("origin").url
+    url = repo().remote("origin").url
     split_url = urlsplit(url)
     # Select the owner and name as regex groups
     parts = re.search(r"[:/]([^:]+)/([^/]*?)(.git)?$", split_url.path)
@@ -115,17 +106,15 @@ def get_repository_owner_and_name() -> Tuple[str, str]:
     return parts.group(1), parts.group(2)
 
 
-@check_repo
 def get_current_head_hash() -> str:
     """
     Get the commit hash of the current HEAD.
 
     :return: The commit hash.
     """
-    return repo.head.commit.name_rev.split(" ")[0]
+    return repo().head.commit.name_rev.split(" ")[0]
 
 
-@check_repo
 @LoggedFunction(logger)
 def commit_new_version(version: str):
     """
@@ -152,13 +141,12 @@ def commit_new_version(version: str):
     )
 
     for declaration in load_version_declarations():
-        git_path: PurePath = PurePath(os.getcwd(), declaration.path).relative_to(repo.working_dir)  # type: ignore
-        repo.git.add(str(git_path))
+        git_path: PurePath = PurePath(os.getcwd(), declaration.path).relative_to(repo().working_dir)  # type: ignore
+        repo().git.add(str(git_path))
 
-    return repo.git.commit(m=message, author=commit_author)
+    return repo().git.commit(m=message, author=commit_author)
 
 
-@check_repo
 @LoggedFunction(logger)
 def update_changelog_file(version: str, content_to_add: str):
     """
@@ -170,11 +158,18 @@ def update_changelog_file(version: str, content_to_add: str):
     changelog_file = config.get("changelog_file")
     changelog_placeholder = config.get("changelog_placeholder")
     git_path = Path(os.getcwd(), changelog_file)
-    if not git_path.exists():
+    if not git_path.exists() or git_path.read_text().strip() == "":
         original_content = f"# Changelog\n\n{changelog_placeholder}\n"
         logger.warning(f"Changelog file not found: {git_path} - creating it.")
     else:
         original_content = git_path.read_text()
+    if (
+        changelog_placeholder not in original_content
+        and "# Changelog" in original_content
+    ):
+        original_content = original_content.replace(
+            "# Changelog", f"# Changelog\n\n{changelog_placeholder}\n"
+        )
 
     if changelog_placeholder not in original_content:
         logger.warning(
@@ -195,12 +190,12 @@ def update_changelog_file(version: str, content_to_add: str):
         ),
     )
     git_path.write_text(updated_content)
-    repo.git.add(str(git_path.relative_to(str(repo.working_dir))))
+    repo().git.add(str(git_path.relative_to(str(repo().working_dir))))
 
 
 def get_changed_files(repo: Repo) -> List[str]:
     """
-    Get untracked / dirty files in the given git repo.
+    Get untracked / dirty files in the given git repo().
 
     :param repo: Git repo to check.
     :return: A list of filenames.
@@ -210,25 +205,23 @@ def get_changed_files(repo: Repo) -> List[str]:
     return [*untracked_files, *dirty_files]
 
 
-@check_repo
 @LoggedFunction(logger)
 def update_additional_files():
     """
     Add specified files to VCS, if they've changed.
     """
-    changed_files = get_changed_files(repo)
+    changed_files = get_changed_files(repo())
 
     include_additional_files = config.get("include_additional_files")
     if include_additional_files:
         for filename in include_additional_files.split(","):
             if filename in changed_files:
                 logger.debug(f"Updated file: {filename}")
-                repo.git.add(filename)
+                repo().git.add(filename)
             else:
                 logger.warning(f"File {filename} shows no changes, cannot update it.")
 
 
-@check_repo
 @LoggedFunction(logger)
 def tag_new_version(version: str):
     """
@@ -237,10 +230,9 @@ def tag_new_version(version: str):
     :param version: The version number used in the tag as a string.
     """
     tag = get_formatted_tag(version)
-    return repo.git.tag("-a", tag, m=tag)
+    return repo().git.tag("-a", tag, m=tag)
 
 
-@check_repo
 @LoggedFunction(logger)
 def push_new_version(
     auth_token: str = None,
@@ -274,8 +266,8 @@ def push_new_version(
             logger.debug("Ignoring token for pushing to the repository.")
 
     try:
-        repo.git.push(server, branch)
-        repo.git.push("--tags", server, branch)
+        repo().git.push(server, branch)
+        repo().git.push("--tags", server, branch)
     except GitCommandError as error:
         message = str(error)
         if auth_token:
@@ -283,7 +275,6 @@ def push_new_version(
         raise GitError(message)
 
 
-@check_repo
 @LoggedFunction(logger)
 def checkout(branch: str):
     """
@@ -291,4 +282,4 @@ def checkout(branch: str):
 
     :param branch: The branch to checkout.
     """
-    return repo.git.checkout(branch)
+    return repo().git.checkout(branch)
